ardt.preprocessors.filters.ButterworthFilter
============================================

.. automodule:: ardt.preprocessors.filters.ButterworthFilter

   
   .. rubric:: Classes

   .. autosummary::
   
      ButterworthFilter
   